This project is archived and is in readonly mode.
Slow Development
-
Stephan Kaag
+1 works for me
-
Wincent Colaiuta
-1 please don't apply these patches in their current form.
Patch 1/2 doesn't actually fix the spelling; it removes the correct spelling and inserts the wrong spelling.
See:
http://dictionary.reference.com/browse/descendant
http://dictionary.reference.com/browse/descendent
"descendent" is an adjective, so could be used to say something like "descendent_classes".
"descendant" is a noun, which is what we need here.
-
Santiago Pastorino
- Milestone cleared.
- Assigned user changed from Yehuda Katz (wycats) to José Valim
As requested by Jeremy, assigned to José.
Also Wincent is right, so don't change the name, leave as descendants -
José Valim
- State changed from open to resolved
I pushed a bunch of commits to solve this issue. Could you please try it out?
-
Jan De Poorter
It still feels a lot slower then on beta4, yet benchmarks show that loading is a lot faster. Are there any good ways in Rails3 to profile a request?
jan-wired:Openminds/sock (master*)$ r benchmarker 10 'User; ActionDispatch::Callbacks.new(Proc.new {}, false).call({})' /Users/jan/.bundle/ruby/1.8/gems/tolk-1.0/lib/tolk/engine.rb:5) user system total real #1 0.840000 0.090000 0.930000 ( 1.259372) -
José Valim
- State changed from resolved to open
Jan, I'm almost sure that in the benchmark script above, most of the time is spent in loading the class User. Could you confirm? And the current results are two times slower than beta4, right?
-
Jan De Poorter
Forget my last post, laptop was under lot of IO load which made results a bit off. With current master this is the result from the benchmark.
jan-wired:Openminds/sock (master*)$ r benchmarker 10 'User; ActionDispatch::Callbacks.new(Proc.new {}, false).call({})' /Users/jan/.bundle/ruby/1.8/gems/tolk-1.0/lib/tolk/engine.rb:5) user system total real #1 0.550000 0.020000 0.570000 ( 0.585960)which is the same speed as with beta4, it's also the same speed when running through the app in a browser. Load times per page of 0.5seconds instead of 3 to 4seconds / request.
Thanks a bunch, for me it is resolved
